==> haskell-protolude-0.3.0-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 protolude
version:              0.3.0
visibility:           public
id:                   protolude-0.3.0-HVvx5KVZpp6nuA6ELN9hL
key:                  protolude-0.3.0-HVvx5KVZpp6nuA6ELN9hL
license:              MIT
copyright:            2016-2020 Stephen Diehl
maintainer:           stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/protolude
synopsis:             A small prelude.
description:          A sensible set of defaults for writing custom Preludes.
category:             Prelude
abi:                  ad85b3549d538f6758b917b618804a18
exposed:              True
exposed-modules:
    Protolude Protolude.Applicative Protolude.Base Protolude.Bifunctor
    Protolude.Bool Protolude.CallStack Protolude.Conv
    Protolude.ConvertText Protolude.Debug Protolude.Either
    Protolude.Error Protolude.Exceptions Protolude.Functor
    Protolude.List Protolude.Monad Protolude.Panic Protolude.Partial
    Protolude.Safe Protolude.Semiring Protolude.Show Protolude.Unsafe

import-dirs:          /usr/lib/ghc-9.0.1/site-local/protolude-0.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/protolude-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/protolude-0.3.0
hs-libraries:         HSprotolude-0.3.0-HVvx5KVZpp6nuA6ELN9hL
depends:
    array-0.5.4.0 async-2.2.3-CNKeORWECfU30PugVlDwF base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 deepseq-1.4.5.0
    ghc-prim-0.7.0 hashable-1.3.3.0-BjQXPnRjTz0I5yXUcLzcAY mtl-2.2.2
    stm-2.5.0.0 text-1.2.4.1 transformers-0.5.6.2
    transformers-compat-0.7-G46eeHH0vduAN6T7RnrFpu

haddock-interfaces:   /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html:         /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-protolude-0.3.0-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 protolude
version:              0.3.0
visibility:           public
id:                   protolude-0.3.0-GCbLWgJx3w93nLiTUCis7f
key:                  protolude-0.3.0-GCbLWgJx3w93nLiTUCis7f
license:              MIT
copyright:            2016-2020 Stephen Diehl
maintainer:           stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/protolude
synopsis:             A small prelude.
description:          A sensible set of defaults for writing custom Preludes.
category:             Prelude
abi:                  25754d1773d01e4d3d0ac3813d492dc0
exposed:              True
exposed-modules:
    Protolude Protolude.Applicative Protolude.Base Protolude.Bifunctor
    Protolude.Bool Protolude.CallStack Protolude.Conv
    Protolude.ConvertText Protolude.Debug Protolude.Either
    Protolude.Error Protolude.Exceptions Protolude.Functor
    Protolude.List Protolude.Monad Protolude.Panic Protolude.Partial
    Protolude.Safe Protolude.Semiring Protolude.Show Protolude.Unsafe

import-dirs:          /usr/lib/ghc-9.0.1/site-local/protolude-0.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/protolude-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/protolude-0.3.0
hs-libraries:         HSprotolude-0.3.0-GCbLWgJx3w93nLiTUCis7f
depends:
    array-0.5.4.0 async-2.2.3-KG7Du60y7DvAqBDAYoSjqL base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 deepseq-1.4.5.0
    ghc-prim-0.7.0 hashable-1.3.3.0-LgC2GKp34OLEabneGtyuCb mtl-2.2.2
    stm-2.5.0.0 text-1.2.4.1 transformers-0.5.6.2
    transformers-compat-0.7-G46eeHH0vduAN6T7RnrFpu

haddock-interfaces:   /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html:         /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
